@@ -1,6 +1,5 @@
 # vim: set ft=perl ts=8 sts=2 sw=2 tw=100 et :
-use strict;
-use warnings;
+use strictures 2;
 use 5.020;
 use experimental qw(signatures postderef);
 use if "$]" >= 5.022, experimental => 're_strict';
@@ -67,7 +66,7 @@ sub acceptance_tests (%options) {
 
       note 'result: ', $result->dump;
       note 'short-circuited result: ', $result_short->dump
-        if not $ENV{NO_SHORT_CIRCUIT} and ($result xor $result_short);
+        if not $ENV{NO_SHORT_CIRCUIT};
 
       die 'results inconsistent between short_circuit = false and true'
         if not $ENV{NO_SHORT_CIRCUIT}
